import type { aws_ecs, aws_iam } from 'aws-cdk-lib';
/**
 * TaskDefinitionOverrides
 */
export interface TaskDefinitionOverrides {
    /**
     * The operating system that your task definitions are running on.
     * A runtimePlatform is supported only for tasks using the Fargate launch type.
     * @default - Undefined.
     * @stability stable
     */
    readonly runtimePlatform?: aws_ecs.RuntimePlatform;
    /**
     * The amount (in MiB) of memory used by the task.
     * For tasks using the Fargate launch type,
     * this field is required and you must use one of the following values, which determines your range of valid values for the cpu parameter:
     *
     * 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB) - Available cpu values: 256 (.25 vCPU)
     *
     * 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB) - Available cpu values: 512 (.5 vCPU)
     *
     * 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB) - Available cpu values: 1024 (1 vCPU)
     *
     * Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB) - Available cpu values: 2048 (2 vCPU)
     *
     * Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB) - Available cpu values: 4096 (4 vCPU)
     *
     * Between 16384 (16 GB) and 61440 (60 GB) in increments of 4096 (4 GB) - Available cpu values: 8192 (8 vCPU)
     *
     * Between 32768 (32 GB) and 122880 (120 GB) in increments of 8192 (8 GB) - Available cpu values: 16384 (16 vCPU)
     * @default 512
     * @stability stable
     */
    readonly memoryLimitMiB?: number;
    /**
     * The amount (in GiB) of ephemeral storage to be allocated to the task.
     * The maximum supported value is 200 GiB.
     *
     * NOTE: This parameter is only supported for tasks hosted on AWS Fargate using platform version 1.4.0 or later.
     * @default 20
     * @stability stable
     */
    readonly ephemeralStorageGiB?: number;
    /**
     * The number of cpu units used by the task.
     * For tasks using the Fargate launch type,
     * this field is required and you must use one of the following values,
     * which determines your range of valid values for the memory parameter:
     *
     * 256 (.25 vCPU) - Available memory values: 512 (0.5 GB), 1024 (1 GB), 2048 (2 GB)
     *
     * 512 (.5 vCPU) - Available memory values: 1024 (1 GB), 2048 (2 GB), 3072 (3 GB), 4096 (4 GB)
     *
     * 1024 (1 vCPU) - Available memory values: 2048 (2 GB), 3072 (3 GB), 4096 (4 GB), 5120 (5 GB), 6144 (6 GB), 7168 (7 GB), 8192 (8 GB)
     *
     * 2048 (2 vCPU) - Available memory values: Between 4096 (4 GB) and 16384 (16 GB) in increments of 1024 (1 GB)
     *
     * 4096 (4 vCPU) - Available memory values: Between 8192 (8 GB) and 30720 (30 GB) in increments of 1024 (1 GB)
     *
     * 8192 (8 vCPU) - Available memory values: Between 16384 (16 GB) and 61440 (60 GB) in increments of 4096 (4 GB)
     *
     * 16384 (16 vCPU) - Available memory values: Between 32768 (32 GB) and 122880 (120 GB) in increments of 8192 (8 GB)
     * @default 256
     * @stability stable
     */
    readonly cpu?: number;
    /**
     * The list of volume definitions for the task.
     * For more information, see
     * [Task Definition Parameter Volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide//task_definition_parameters.html#volumes).
     * @default - No volumes are passed to the Docker daemon on a container instance.
     * @stability stable
     */
    readonly volumes?: Array<aws_ecs.Volume>;
    /**
     * The name of the IAM role that grants containers in the task permission to call AWS APIs on your behalf.
     * @default - A task role is automatically created for you.
     * @stability stable
     */
    readonly taskRole?: aws_iam.IRole;
    /**
     * The configuration details for the App Mesh proxy.
     * @default - No proxy configuration.
     * @stability stable
     */
    readonly proxyConfiguration?: aws_ecs.ProxyConfiguration;
    /**
     * The name of a family that this task definition is registered to.
     * A family groups multiple versions of a task definition.
     * @default - Automatically generated name.
     * @stability stable
     */
    readonly family?: string;
    /**
     * The name of the IAM task execution role that grants the ECS agent permission to call AWS APIs on your behalf.
     * The role will be used to retrieve container images from ECR and create CloudWatch log groups.
     * @default - An execution role will be automatically created if you use ECR images in your task definition.
     * @stability stable
     */
    readonly executionRole?: aws_iam.IRole;
}
